import { AbstractFileSystem } from "./AbstractFileSystem";
import { CopyOptions, DeleteOptions, Directory, Entry, HeadOptions, MoveOptions, Stats, URLOptions } from "./core";
import { FileSystemError } from "./errors";
interface ErrorParams {
    code?: number;
    e?: any;
    message?: string;
    [key: string]: any;
}
export declare abstract class AbstractEntry implements Entry {
    readonly fs: AbstractFileSystem;
    readonly path: string;
    stats: Stats | undefined | null;
    constructor(fs: AbstractFileSystem, path: string);
    copy(to: Entry, options?: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    cp: (to: Entry, options?: CopyOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    del: (options?: DeleteOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    delete(options?: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    getParent(): Directory;
    move(to: Entry, options?: MoveOptions, errors?: FileSystemError[]): Promise<boolean>;
    mv: (to: Entry, options?: MoveOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    patch: (props: Stats, options?: HeadOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    remove: (options?: DeleteOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    rm: (options?: DeleteOptions | undefined, errors?: FileSystemError[] | undefined) => Promise<boolean>;
    stat(options?: HeadOptions): Promise<Stats>;
    toString: () => string;
    toURL(options?: URLOptions): Promise<string>;
    abstract _copy(entry: Entry, options: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _deleteExisting(option: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _validate(options?: HeadOptions): Promise<void>;
    abstract head(options?: HeadOptions): Promise<Stats>;
    abstract head(options?: HeadOptions, errors?: FileSystemError[]): Promise<Stats | null>;
    protected $delete(options: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    protected _afterDelete(result: boolean, options: DeleteOptions, error?: FileSystemError): Promise<void>;
    protected _beforeDelete(options: DeleteOptions): Promise<boolean | null> | null;
    protected _createError(name: string, params?: ErrorParams): FileSystemError;
    protected _createNoModificationAllowedError(params?: ErrorParams): FileSystemError;
    protected _createNotFoundError(params?: ErrorParams): FileSystemError;
    protected _createNotReadableError(params?: ErrorParams): FileSystemError;
    protected _createTypeMismatchError(params?: ErrorParams): FileSystemError;
    protected _handleNoModificationAllowedError(params: ErrorParams, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleNotFoundError(params: ErrorParams, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleNotReadableError(params: ErrorParams, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleTypeMismatchError(params: ErrorParams, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
}
export {};
//# sourceMappingURL=AbstractEntry.d.ts.map